from setuptools import setup, find_packages
from distutils.command.sdist import sdist

# Custom class to support specifying micro version in the command line.
# This will be used for integration with TeamCity
class custom_sdist(sdist):

    user_options = sdist.user_options + [ ('micro-version=', None, "Package's micro version number")]

    def initialize_options(self):
        sdist.initialize_options(self)
        self.micro_version = None

    def finalize_options(self):
        #Set default value
        if self.micro_version is None:
            self.micro_version = "0"
        sdist.finalize_options(self)

    def run(self):
        if self.micro_version:
            self.distribution.metadata.version += "." + self.micro_version

        sdist.run(self)


#Get requirements from requirements.txt file
with open('requirements.txt') as f:
    install_requires = f.readlines()
#Remove "\n" from each item
install_requires = map(lambda s: s.strip(), install_requires)


setup(
    cmdclass={ 'sdist': custom_sdist },
    name='tlib',
    version='1.2',
    packages=find_packages(),
    author='Quality Assurance Automation @ Yellow Pages Group',
    description="""Packages to help the wayward QA tester.
        Contains :
            - HttpRequestor : Facilitates communication to REST APIs
            - SoapRequestor : Facilitates communication to SOAP APIs
            - SpiraModerator : Fetches and updates data from SpiraTeam
            - JiraModerator : Fetches and updates issues in Jira
            - WtpHelper : Sends test requests to WebPagetest and returns test results
            """,
    install_requires=install_requires,
    # the following makes a plugin available to py.test
    entry_points = {
        'pytest11': [
            'selenium = pytest_auto.selenium_plugin',
            'yp_auto = pytest_auto.yp_auto',
        ]
    },
    package_data  = {'tlib': ['asset/*.*',
                              'asset/selenium/*.*',
                              'asset/selenium/IE/Win32_2.39.0/*.*',
                              'asset/selenium/IE/x64_2.39.0/*.*',
                              'asset/wpt_batch_lib/*.*',
                              'config/*.*',
                              'templates/*.*']},
)

